@@ -77,13 +77,13 @@ tie %translations, 'Tie::IxHash', (
     q[toutes les valeurs %s],
 
     q[%(modal_verb)s satisfy all of the following],
-    q[%(modal_verb)s satisfaire ÃÂÃÂ  toutes les conditions suivantes],
+    q[%(modal_verb)s satisfaire ÃÂÃÂÃÂÃÂ  toutes les conditions suivantes],
 
     q[%(modal_verb)s satisfy one of the following],
     q[%(modal_verb)s satisfaire l'une des conditions suivantes],
 
     q[%(modal_verb)s satisfy none of the following],
-    q[%(modal_verb)s satisfaire ÃÂÃÂ  aucune des conditions suivantes],
+    q[%(modal_verb)s satisfaire ÃÂÃÂÃÂÃÂ  aucune des conditions suivantes],
 
     # type: BaseType
 
@@ -104,10 +104,10 @@ tie %translations, 'Tie::IxHash', (
     q[nombres entiers],
 
     q[%(modal_verb)s be divisible by %s],
-    q[%(modal_verb)s ÃÂÃÂªtre divisible par %s],
+    q[%(modal_verb)s ÃÂÃÂÃÂÃÂªtre divisible par %s],
 
     q[%(modal_verb)s leave a remainder of %2$s when divided by %1$s],
-    q[%(modal_verb)s laisser un reste %2$s si divisÃÂÃÂ© par %1$s],
+    q[%(modal_verb)s laisser un reste %2$s si divisÃÂÃÂÃÂÃÂ© par %1$s],
 
 );
 
@@ -126,7 +126,7 @@ Data::Sah::Lang::fr_FR - fr_FR locale
 
 =head1 VERSION
 
-This document describes version 0.56 of Data::Sah::Lang::fr_FR (from Perl distribution Perinci-CmdLine-Any-Bundled version 0.02 version 0.01 version 0.01), released on 2015-05-13.
+This document describes version 0.56 of Data::Sah::Lang::fr_FR (from Perl distribution Perinci-CmdLine-Any-Bundled version 0.03 version 0.02 version 0.01 version 0.01), released on 2015-05-13.
 
 =for Pod::Coverage .+
 
